.. OpenPaperwork-GTK documentation master file, created by
   sphinx-quickstart on Sat Dec 14 13:12:28 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to OpenPaperwork-GTK's documentation!
=============================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
